@@ -248,11 +248,13 @@ static void sql_resource_destroy(void *session, void *res)
                                
                 for ( i = 0; i < resource->ncolumn; i++ ) {
                         field = &row->fields[i];
-                        free(field->data);
+               
+                        if ( field->data )
+                                free(field->data);
                 }
                 
                 free(row->fields);
-                                
+                
                 prelude_list_del(&row->list);
                 free(row);
         }
@@ -482,6 +484,9 @@ static int sql_build_constraint_string(prelude_string_t *out, const char *field,
         if ( ! value )
                 value = "";
 
+        if ( operator & IDMEF_CRITERION_OPERATOR_NOCASE )
+                return prelude_string_sprintf(out, "lower(%s) %s lower(%s)", field, op_str, value);
+                
         return prelude_string_sprintf(out, "%s %s %s", field, op_str, value);
 }
 
